@@ -853,4 +853,38 @@ void zhttp_init_tls(void){
 	
 }
 
-#endif
\ No newline at end of file
+#endif
+
+char *http_get_header(struct zhttp *http, const char *header_name){
+
+	if (http->dataofs < 0) return NULL;
+
+	char *c;
+	for (c = http->response->buf; *c != '\0'; c++){
+		char *colon = strchr(c, ':');
+		char *lf = strchr(colon + 1, '\n');
+		int n = Z_MIN(colon - c, lf - c);
+
+		if (colon != NULL){
+			if (strncasecmp(c, header_name, n) == 0){
+				char *ct = g_strndup(colon + 1, lf - (colon + 1));
+				char *ret = z_strdup_trim(ct);
+				g_free(ct);
+				return ret;
+			}
+		}
+		c = lf;
+	}
+	return NULL;
+}
+
+int http_is_content_type(struct zhttp *http, const char *content_type){
+	int ret = 0;
+
+	char *ct = http_get_header(http, "content-type");
+	if (!ct) return ret;
+
+	ret = (strcasecmp(ct, content_type) == 0);
+	g_free(ct);
+	return ret;
+}
